# HANDCRIC

This is a library which hosts a game of Hand Cricket which you can
enjoy while doing your work

Developed by Chiranjeev Mishra

## Example of How to use it 

```python
import handcric as h

h.match()
#Now you can play the game
```
